# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AccessControlEntryAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Action object."""

    PERMIT = "Permit"
    DENY = "Deny"


class AppServicePlanRestrictions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """App Service plans this offer is restricted to."""

    NONE = "None"
    FREE = "Free"
    SHARED = "Shared"
    BASIC = "Basic"
    STANDARD = "Standard"
    PREMIUM = "Premium"


class AutoHealActionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Predefined action to be taken."""

    RECYCLE = "Recycle"
    LOG_EVENT = "LogEvent"
    CUSTOM_ACTION = "CustomAction"


class AzureResourceType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the Azure resource the hostname is assigned to."""

    WEBSITE = "Website"
    TRAFFIC_MANAGER = "TrafficManager"


class AzureStorageState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State of the storage account."""

    OK = "Ok"
    INVALID_CREDENTIALS = "InvalidCredentials"
    INVALID_SHARE = "InvalidShare"


class AzureStorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of storage."""

    AZURE_FILES = "AzureFiles"
    AZURE_BLOB = "AzureBlob"


class BackupItemStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Backup status."""

    IN_PROGRESS = "InProgress"
    FAILED = "Failed"
    SUCCEEDED = "Succeeded"
    TIMED_OUT = "TimedOut"
    CREATED = "Created"
    SKIPPED = "Skipped"
    PARTIALLY_SUCCEEDED = "PartiallySucceeded"
    DELETE_IN_PROGRESS = "DeleteInProgress"
    DELETE_FAILED = "DeleteFailed"
    DELETED = "Deleted"


class BackupRestoreOperationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Operation type."""

    DEFAULT = "Default"
    CLONE = "Clone"
    RELOCATION = "Relocation"
    SNAPSHOT = "Snapshot"
    CLOUD_FS = "CloudFS"


class BuiltInAuthenticationProvider(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The default authentication provider to use when multiple providers are configured.
    This setting is only needed if multiple providers are configured and the unauthenticated client
    action is set to "RedirectToLoginPage".
    """

    AZURE_ACTIVE_DIRECTORY = "AzureActiveDirectory"
    FACEBOOK = "Facebook"
    GOOGLE = "Google"
    MICROSOFT_ACCOUNT = "MicrosoftAccount"
    TWITTER = "Twitter"


class CertificateOrderActionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Action type."""

    CERTIFICATE_ISSUED = "CertificateIssued"
    CERTIFICATE_ORDER_CANCELED = "CertificateOrderCanceled"
    CERTIFICATE_ORDER_CREATED = "CertificateOrderCreated"
    CERTIFICATE_REVOKED = "CertificateRevoked"
    DOMAIN_VALIDATION_COMPLETE = "DomainValidationComplete"
    FRAUD_DETECTED = "FraudDetected"
    ORG_NAME_CHANGE = "OrgNameChange"
    ORG_VALIDATION_COMPLETE = "OrgValidationComplete"
    SAN_DROP = "SanDrop"
    FRAUD_CLEARED = "FraudCleared"
    CERTIFICATE_EXPIRED = "CertificateExpired"
    CERTIFICATE_EXPIRATION_WARNING = "CertificateExpirationWarning"
    FRAUD_DOCUMENTATION_REQUIRED = "FraudDocumentationRequired"
    UNKNOWN = "Unknown"


class CertificateOrderStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current order status."""

    PENDINGISSUANCE = "Pendingissuance"
    ISSUED = "Issued"
    REVOKED = "Revoked"
    CANCELED = "Canceled"
    DENIED = "Denied"
    PENDINGREVOCATION = "Pendingrevocation"
    PENDING_REKEY = "PendingRekey"
    UNUSED = "Unused"
    EXPIRED = "Expired"
    NOT_SUBMITTED = "NotSubmitted"


class CertificateProductType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Certificate product type."""

    STANDARD_DOMAIN_VALIDATED_SSL = "StandardDomainValidatedSsl"
    STANDARD_DOMAIN_VALIDATED_WILD_CARD_SSL = "StandardDomainValidatedWildCardSsl"


class Channels(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """List of channels that this recommendation can apply."""

    NOTIFICATION = "Notification"
    API = "Api"
    EMAIL = "Email"
    WEBHOOK = "Webhook"
    ALL = "All"


class CheckNameResourceTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Resource type used for verification."""

    SITE = "Site"
    SLOT = "Slot"
    HOSTING_ENVIRONMENT = "HostingEnvironment"
    PUBLISHING_USER = "PublishingUser"
    MICROSOFT_WEB_SITES = "Microsoft.Web/sites"
    MICROSOFT_WEB_SITES_SLOTS = "Microsoft.Web/sites/slots"
    MICROSOFT_WEB_HOSTING_ENVIRONMENTS = "Microsoft.Web/hostingEnvironments"
    MICROSOFT_WEB_PUBLISHING_USERS = "Microsoft.Web/publishingUsers"


class CloneAbilityResult(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Name of app."""

    CLONEABLE = "Cloneable"
    PARTIALLY_CLONEABLE = "PartiallyCloneable"
    NOT_CLONEABLE = "NotCloneable"


class ComputeModeOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Shared/dedicated workers."""

    SHARED = "Shared"
    DEDICATED = "Dedicated"
    DYNAMIC = "Dynamic"


class ConnectionStringType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of database."""

    MY_SQL = "MySql"
    SQL_SERVER = "SQLServer"
    SQL_AZURE = "SQLAzure"
    CUSTOM = "Custom"
    NOTIFICATION_HUB = "NotificationHub"
    SERVICE_BUS = "ServiceBus"
    EVENT_HUB = "EventHub"
    API_HUB = "ApiHub"
    DOC_DB = "DocDb"
    REDIS_CACHE = "RedisCache"
    POSTGRE_SQL = "PostgreSQL"


class ContinuousWebJobStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Job status."""

    INITIALIZING = "Initializing"
    STARTING = "Starting"
    RUNNING = "Running"
    PENDING_RESTART = "PendingRestart"
    STOPPED = "Stopped"


class CustomHostNameDnsRecordType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the DNS record."""

    C_NAME = "CName"
    A = "A"


class DatabaseType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Database type (e.g. SqlAzure / MySql)."""

    SQL_AZURE = "SqlAzure"
    MY_SQL = "MySql"
    LOCAL_MY_SQL = "LocalMySql"
    POSTGRE_SQL = "PostgreSql"


class DnsType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current DNS type."""

    AZURE_DNS = "AzureDns"
    DEFAULT_DOMAIN_REGISTRAR_DNS = "DefaultDomainRegistrarDns"


class DnsVerificationTestResult(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """DNS verification test result."""

    PASSED = "Passed"
    FAILED = "Failed"
    SKIPPED = "Skipped"


class DomainPatchResourcePropertiesDomainNotRenewableReasonsItem(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """DomainPatchResourcePropertiesDomainNotRenewableReasonsItem."""

    REGISTRATION_STATUS_NOT_SUPPORTED_FOR_RENEWAL = "RegistrationStatusNotSupportedForRenewal"
    EXPIRATION_NOT_IN_RENEWAL_TIME_RANGE = "ExpirationNotInRenewalTimeRange"
    SUBSCRIPTION_NOT_ACTIVE = "SubscriptionNotActive"


class DomainPropertiesDomainNotRenewableReasonsItem(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """DomainPropertiesDomainNotRenewableReasonsItem."""

    REGISTRATION_STATUS_NOT_SUPPORTED_FOR_RENEWAL = "RegistrationStatusNotSupportedForRenewal"
    EXPIRATION_NOT_IN_RENEWAL_TIME_RANGE = "ExpirationNotInRenewalTimeRange"
    SUBSCRIPTION_NOT_ACTIVE = "SubscriptionNotActive"


class DomainStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Domain registration status."""

    ACTIVE = "Active"
    AWAITING = "Awaiting"
    CANCELLED = "Cancelled"
    CONFISCATED = "Confiscated"
    DISABLED = "Disabled"
    EXCLUDED = "Excluded"
    EXPIRED = "Expired"
    FAILED = "Failed"
    HELD = "Held"
    LOCKED = "Locked"
    PARKED = "Parked"
    PENDING = "Pending"
    RESERVED = "Reserved"
    REVERTED = "Reverted"
    SUSPENDED = "Suspended"
    TRANSFERRED = "Transferred"
    UNKNOWN = "Unknown"
    UNLOCKED = "Unlocked"
    UNPARKED = "Unparked"
    UPDATED = "Updated"
    JSON_CONVERTER_FAILED = "JsonConverterFailed"


class DomainType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Valid values are Regular domain: Azure will charge the full price of domain registration,
    SoftDeleted: Purchasing this domain will simply restore it and this operation will not cost
    anything.
    """

    REGULAR = "Regular"
    SOFT_DELETED = "SoftDeleted"


class Enum3(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enum3."""

    WINDOWS = "Windows"
    LINUX = "Linux"
    WINDOWS_FUNCTIONS = "WindowsFunctions"
    LINUX_FUNCTIONS = "LinuxFunctions"


class Enum4(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enum4."""

    WINDOWS = "Windows"
    LINUX = "Linux"
    WINDOWS_FUNCTIONS = "WindowsFunctions"
    LINUX_FUNCTIONS = "LinuxFunctions"


class FrequencyUnit(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The unit of time for how often the backup should be executed (e.g. for weekly backup, this
    should be set to Day and FrequencyInterval should be set to 7).
    """

    DAY = "Day"
    HOUR = "Hour"


class FtpsState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State of FTP / FTPS service."""

    ALL_ALLOWED = "AllAllowed"
    FTPS_ONLY = "FtpsOnly"
    DISABLED = "Disabled"


class HostingEnvironmentStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current status of the App Service Environment."""

    PREPARING = "Preparing"
    READY = "Ready"
    SCALING = "Scaling"
    DELETING = "Deleting"


class HostNameType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the hostname."""

    VERIFIED = "Verified"
    MANAGED = "Managed"


class HostType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Indicates whether the hostname is a standard or repository hostname."""

    STANDARD = "Standard"
    REPOSITORY = "Repository"


class InAvailabilityReasonType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """:code:`<code>Invalid</code>` indicates the name provided does not match Azure App Service
    naming requirements. :code:`<code>AlreadyExists</code>` indicates that the name is already in
    use and is therefore unavailable.
    """

    INVALID = "Invalid"
    ALREADY_EXISTS = "AlreadyExists"


class InternalLoadBalancingMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies which endpoints to serve internally in the Virtual Network for the App Service
    Environment.
    """

    NONE = "None"
    WEB = "Web"
    PUBLISHING = "Publishing"


class IpFilterTag(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Defines what this IP filter will be used for. This is to support IP filtering on proxies."""

    DEFAULT = "Default"
    XFF_PROXY = "XffProxy"


class IssueType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Represents the type of the Detector."""

    SERVICE_INCIDENT = "ServiceIncident"
    APP_DEPLOYMENT = "AppDeployment"
    APP_CRASH = "AppCrash"
    RUNTIME_ISSUE_DETECTED = "RuntimeIssueDetected"
    ASE_DEPLOYMENT = "AseDeployment"
    USER_ISSUE = "UserIssue"
    PLATFORM_ISSUE = "PlatformIssue"
    OTHER = "Other"


class KeyVaultSecretStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Status of the Key Vault secret."""

    INITIALIZED = "Initialized"
    WAITING_ON_CERTIFICATE_ORDER = "WaitingOnCertificateOrder"
    SUCCEEDED = "Succeeded"
    CERTIFICATE_ORDER_FAILED = "CertificateOrderFailed"
    OPERATION_NOT_PERMITTED_ON_KEY_VAULT = "OperationNotPermittedOnKeyVault"
    AZURE_SERVICE_UNAUTHORIZED_TO_ACCESS_KEY_VAULT = "AzureServiceUnauthorizedToAccessKeyVault"
    KEY_VAULT_DOES_NOT_EXIST = "KeyVaultDoesNotExist"
    KEY_VAULT_SECRET_DOES_NOT_EXIST = "KeyVaultSecretDoesNotExist"
    UNKNOWN_ERROR = "UnknownError"
    EXTERNAL_PRIVATE_KEY = "ExternalPrivateKey"
    UNKNOWN = "Unknown"


class LogLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Log level."""

    OFF = "Off"
    VERBOSE = "Verbose"
    INFORMATION = "Information"
    WARNING = "Warning"
    ERROR = "Error"


class ManagedPipelineMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Managed pipeline mode."""

    INTEGRATED = "Integrated"
    CLASSIC = "Classic"


class ManagedServiceIdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of managed service identity."""

    SYSTEM_ASSIGNED = "SystemAssigned"
    USER_ASSIGNED = "UserAssigned"
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned, UserAssigned"
    NONE = "None"


class MSDeployLogEntryType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Log entry type."""

    MESSAGE = "Message"
    WARNING = "Warning"
    ERROR = "Error"


class MSDeployProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state."""

    ACCEPTED = "accepted"
    RUNNING = "running"
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    CANCELED = "canceled"


class MySqlMigrationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of migration operation to be done."""

    LOCAL_TO_REMOTE = "LocalToRemote"
    REMOTE_TO_LOCAL = "RemoteToLocal"


class NotificationLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Level indicating how critical this recommendation can impact."""

    CRITICAL = "Critical"
    WARNING = "Warning"
    INFORMATION = "Information"
    NON_URGENT_SUGGESTION = "NonUrgentSuggestion"


class OperationStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The current status of the operation."""

    IN_PROGRESS = "InProgress"
    FAILED = "Failed"
    SUCCEEDED = "Succeeded"
    TIMED_OUT = "TimedOut"
    CREATED = "Created"


class ProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Status of certificate order."""

    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    IN_PROGRESS = "InProgress"
    DELETING = "Deleting"


class PublicCertificateLocation(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Public Certificate Location."""

    CURRENT_USER_MY = "CurrentUserMy"
    LOCAL_MACHINE_MY = "LocalMachineMy"
    UNKNOWN = "Unknown"


class PublishingProfileFormat(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Name of the format. Valid values are:
    FileZilla3
    WebDeploy -- default
    Ftp.
    """

    FILE_ZILLA3 = "FileZilla3"
    WEB_DEPLOY = "WebDeploy"
    FTP = "Ftp"


class RedundancyMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Site redundancy mode."""

    NONE = "None"
    MANUAL = "Manual"
    FAILOVER = "Failover"
    ACTIVE_ACTIVE = "ActiveActive"
    GEO_REDUNDANT = "GeoRedundant"


class RenderingType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Rendering Type."""

    NO_GRAPH = "NoGraph"
    TABLE = "Table"
    TIME_SERIES = "TimeSeries"
    TIME_SERIES_PER_INSTANCE = "TimeSeriesPerInstance"


class ResourceNotRenewableReason(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """ResourceNotRenewableReason."""

    REGISTRATION_STATUS_NOT_SUPPORTED_FOR_RENEWAL = "RegistrationStatusNotSupportedForRenewal"
    EXPIRATION_NOT_IN_RENEWAL_TIME_RANGE = "ExpirationNotInRenewalTimeRange"
    SUBSCRIPTION_NOT_ACTIVE = "SubscriptionNotActive"


class ResourceScopeType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Name of a resource type this recommendation applies, e.g. Subscription, ServerFarm, Site."""

    SERVER_FARM = "ServerFarm"
    SUBSCRIPTION = "Subscription"
    WEB_SITE = "WebSite"


class RouteType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of route this is:
    DEFAULT - By default, every app has routes to the local address ranges specified by RFC1918
    INHERITED - Routes inherited from the real Virtual Network routes
    STATIC - Static route set on the app only

    These values will be used for syncing an app's routes with those from a Virtual Network.
    """

    DEFAULT = "DEFAULT"
    INHERITED = "INHERITED"
    STATIC = "STATIC"


class ScmType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """SCM type."""

    NONE = "None"
    DROPBOX = "Dropbox"
    TFS = "Tfs"
    LOCAL_GIT = "LocalGit"
    GIT_HUB = "GitHub"
    CODE_PLEX_GIT = "CodePlexGit"
    CODE_PLEX_HG = "CodePlexHg"
    BITBUCKET_GIT = "BitbucketGit"
    BITBUCKET_HG = "BitbucketHg"
    EXTERNAL_GIT = "ExternalGit"
    EXTERNAL_HG = "ExternalHg"
    ONE_DRIVE = "OneDrive"
    VSO = "VSO"


class SiteAvailabilityState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Management information availability state for the app."""

    NORMAL = "Normal"
    LIMITED = "Limited"
    DISASTER_RECOVERY_MODE = "DisasterRecoveryMode"


class SiteExtensionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Site extension type."""

    GALLERY = "Gallery"
    WEB_ROOT = "WebRoot"


class SiteLoadBalancing(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Site load balancing."""

    WEIGHTED_ROUND_ROBIN = "WeightedRoundRobin"
    LEAST_REQUESTS = "LeastRequests"
    LEAST_RESPONSE_TIME = "LeastResponseTime"
    WEIGHTED_TOTAL_TRAFFIC = "WeightedTotalTraffic"
    REQUEST_HASH = "RequestHash"


class SkuName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """SkuName."""

    FREE = "Free"
    SHARED = "Shared"
    BASIC = "Basic"
    STANDARD = "Standard"
    PREMIUM = "Premium"
    DYNAMIC = "Dynamic"
    ISOLATED = "Isolated"
    PREMIUM_V2 = "PremiumV2"
    ELASTIC_PREMIUM = "ElasticPremium"
    ELASTIC_ISOLATED = "ElasticIsolated"


class SolutionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of Solution."""

    QUICK_SOLUTION = "QuickSolution"
    DEEP_INVESTIGATION = "DeepInvestigation"
    BEST_PRACTICES = "BestPractices"


class SslState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """SSL type."""

    DISABLED = "Disabled"
    SNI_ENABLED = "SniEnabled"
    IP_BASED_ENABLED = "IpBasedEnabled"


class StatusOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """App Service plan status."""

    READY = "Ready"
    PENDING = "Pending"
    CREATING = "Creating"


class SupportedTlsVersions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """MinTlsVersion: configures the minimum version of TLS required for SSL requests."""

    ONE0 = "1.0"
    ONE1 = "1.1"
    ONE2 = "1.2"


class TriggeredWebJobStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Job status."""

    SUCCESS = "Success"
    FAILED = "Failed"
    ERROR = "Error"


class UnauthenticatedClientAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The action to take when an unauthenticated client attempts to access the app."""

    REDIRECT_TO_LOGIN_PAGE = "RedirectToLoginPage"
    ALLOW_ANONYMOUS = "AllowAnonymous"


class UsageState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State indicating whether the app has exceeded its quota usage. Read-only."""

    NORMAL = "Normal"
    EXCEEDED = "Exceeded"


class ValidateResourceTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Resource type used for verification."""

    SERVER_FARM = "ServerFarm"
    SITE = "Site"


class WebJobType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Job type."""

    CONTINUOUS = "Continuous"
    TRIGGERED = "Triggered"


class WorkerSizeOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Size of the machines."""

    SMALL = "Small"
    MEDIUM = "Medium"
    LARGE = "Large"
    D1 = "D1"
    D2 = "D2"
    D3 = "D3"
    DEFAULT = "Default"



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.cognitiveservices import CognitiveServicesManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestCognitiveServicesManagementUsagesOperations(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(CognitiveServicesManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_usages_list(self, resource_group):
        response = self.client.usages.list(
            location="str",
            api_version="2025-04-01-preview",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...



#!/usr/bin/env python

# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

# This script is used to execute pylint within a tox environment. Depending on which package is being executed against,
# a failure may be suppressed.

from subprocess import check_call, CalledProcessError
import argparse
import os
import logging
from prep_sphinx_env import should_build_docs
import sys
import shutil
from pathlib import Path

from ci_tools.parsing import ParsedSetup

logging.getLogger().setLevel(logging.INFO)

root_dir = os.path.abspath(os.path.join(os.path.abspath(__file__), "..", "..", ".."))
generate_mgmt_script = os.path.join(root_dir, "doc/sphinx/generate_doc.py")

def is_mgmt_package(pkg_name):
    return pkg_name != "azure-mgmt-core" and ("mgmt" in pkg_name or "cognitiveservices" in pkg_name)

def copy_existing_docs(source, target):
    for file in os.listdir(source):
        logging.info("Copying {}".format(file))
        shutil.copy(os.path.join(source, file), target)

def sphinx_apidoc(working_directory: str, namespace: str) -> None:
    working_doc_folder = os.path.join(args.working_directory, "unzipped", "doc")
    command_array = [
            "sphinx-apidoc",
            "--no-toc",
            "--module-first",
            "-o",
            os.path.join(args.working_directory, "unzipped/docgen"),   # This is the output folder
            os.path.join(args.working_directory, "unzipped/"),         # This is the input folder
            os.path.join(args.working_directory, "unzipped/test*"),    # Starting here this, is excluded
            os.path.join(args.working_directory, "unzipped/example*"),
            os.path.join(args.working_directory, "unzipped/sample*"),
            os.path.join(args.working_directory, "unzipped/setup.py"),
        ]

    try:
        # if a `doc` folder exists, just leverage the sphinx sources found therein.
        if os.path.exists(working_doc_folder):
            logging.info("Copying files into sphinx source folder.")
            copy_existing_docs(working_doc_folder, os.path.join(args.working_directory, "unzipped/docgen"))

        # otherwise, we will run sphinx-apidoc to generate the sources
        else:
            logging.info("Sphinx api-doc command: {}".format(command_array))
            check_call(
                command_array
            )
            # We need to clean "azure.rst", and other RST before the main namespaces, as they are never
            # used and will log as a warning later by sphinx-build, which is blocking strict_sphinx
            base_path = Path(os.path.join(args.working_directory, "unzipped/docgen/"))
            namespace = namespace.rpartition('.')[0]
            while namespace:
                rst_file_to_delete = base_path / f"{namespace}.rst"
                logging.info(f"Removing {rst_file_to_delete}")
                rst_file_to_delete.unlink()
                namespace = namespace.rpartition('.')[0]
    except CalledProcessError as e:
        logging.error(
            "sphinx-apidoc failed for path {} exited with error {}".format(
                args.working_directory, e.returncode
            )
        )
        exit(1)

def mgmt_apidoc(working_directory: str, target_folder: str):
    command_array = [
        sys.executable,
        generate_mgmt_script,
        "-p",
        target_folder,
        "-o",
        working_directory,
        "--verbose",
        ]

    try:
        logging.info("Command to generate management sphinx sources: {}".format(command_array))

        check_call(
            command_array
        )
    except CalledProcessError as e:
        logging.error(
            "script failed for path {} exited with error {}".format(
                args.working_directory, e.returncode
            )
        )
        exit(1)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description="Run sphinx-apidoc against target folder. Handles management generation if necessary."
    )

    parser.add_argument(
        "-w",
        "--workingdir",
        dest="working_directory",
        help="The unzipped package directory on disk. Usually {distdir}/unzipped/",
        required=True,
    )

    parser.add_argument(
        "-r",
        "--root",
        dest="package_root",
        help="",
        required=True,
    )

    args = parser.parse_args()

    target_dir = os.path.abspath(args.working_directory)
    package_dir = os.path.abspath(args.package_root)
    output_directory = os.path.join(target_dir, "unzipped/docgen")

    pkg_details = ParsedSetup.from_path(package_dir)

    if should_build_docs(pkg_details.name):
        if is_mgmt_package(pkg_details.name):
            mgmt_apidoc(output_directory, pkg_details.folder)
        else:
            sphinx_apidoc(args.working_directory, pkg_details.namespace)
    else:
        logging.info("Skipping sphinx source generation for {}".format(pkg_details.name))


# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.devtestlabs import DevTestLabsClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestDevTestLabsDisksOperations(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(DevTestLabsClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list(self, resource_group):
        response = self.client.disks.list(
            resource_group_name=resource_group.name,
            lab_name="str",
            user_name="str",
            api_version="2018-09-15",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get(self, resource_group):
        response = self.client.disks.get(
            resource_group_name=resource_group.name,
            lab_name="str",
            user_name="str",
            name="str",
            api_version="2018-09-15",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_create_or_update(self, resource_group):
        response = self.client.disks.begin_create_or_update(
            resource_group_name=resource_group.name,
            lab_name="str",
            user_name="str",
            name="str",
            disk={
                "createdDate": "2020-02-20 00:00:00",
                "diskBlobName": "str",
                "diskSizeGiB": 0,
                "diskType": "str",
                "diskUri": "str",
                "hostCaching": "str",
                "id": "str",
                "leasedByLabVmId": "str",
                "location": "str",
                "managedDiskId": "str",
                "name": "str",
                "provisioningState": "str",
                "storageAccountId": "str",
                "tags": {"str": "str"},
                "type": "str",
                "uniqueIdentifier": "str",
            },
            api_version="2018-09-15",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_delete(self, resource_group):
        response = self.client.disks.begin_delete(
            resource_group_name=resource_group.name,
            lab_name="str",
            user_name="str",
            name="str",
            api_version="2018-09-15",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_update(self, resource_group):
        response = self.client.disks.update(
            resource_group_name=resource_group.name,
            lab_name="str",
            user_name="str",
            name="str",
            api_version="2018-09-15",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_attach(self, resource_group):
        response = self.client.disks.begin_attach(
            resource_group_name=resource_group.name,
            lab_name="str",
            user_name="str",
            name="str",
            api_version="2018-09-15",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_detach(self, resource_group):
        response = self.client.disks.begin_detach(
            resource_group_name=resource_group.name,
            lab_name="str",
            user_name="str",
            name="str",
            api_version="2018-09-15",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...



import os
import re
import json
import logging
import time
import urllib.parse
from datetime import date, datetime
from typing import Set, List, Dict
from random import randint
from pathlib import Path
from github import Github
from github.Repository import Repository

from utils import IssuePackage, REQUEST_REPO, AUTO_ASSIGN_LABEL, AUTO_PARSE_LABEL, get_origin_link_and_tag,\
    MULTI_LINK_LABEL, INCONSISTENT_TAG, TYPESPEC_LABEL

_LOG = logging.getLogger(__name__)

# assignee dict which will be assigned to handle issues
_LANGUAGE_OWNER = {'msyyc'}

# 'github assignee': 'token'
_ASSIGNEE_TOKEN = os.getenv('AZURESDK_BOT_TOKEN')

_SWAGGER_URL = 'https://github.com/Azure/azure-rest-api-specs/blob/main/specification'
_SWAGGER_PULL = 'https://github.com/Azure/azure-rest-api-specs/pull'
_HINTS = ["FirstGA", "FirstBeta", "HoldOn", "OnTime", "ForCLI", TYPESPEC_LABEL]


class IssueProcess:
    """
    # won't be changed anymore after __init__
    owner = ''  # issue owner
    assignee_candidates = {}  # assignee candidates who will be assigned to handle issue
    language_owner = {}  # language owner who may handle issue

    # will be changed by order
    issue_package = None  # issue that needs to handle
    assignee = ''
    bot_advice = []  # bot advice to help SDK owner
    target_readme_tag = ''  # swagger content that customers want
    readme_link = ''  # https link which swagger definition is in
    default_readme_tag = ''  # configured in `README.md`
    package_name = ''  # target package name
    target_date = ''  # target release date asked by customer
    date_from_target = 0
    spec_repo = None  # local swagger repo path
    """

    def __init__(self, issue_package: IssuePackage, request_repo: Repository,
                 assignee_candidates: Set[str], language_owner: Set[str]):
        self.issue_package = issue_package
        self.assignee = issue_package.issue.assignee.login if issue_package.issue.assignee else ''
        self.owner = issue_package.issue.user.login
        self.created_time = issue_package.issue.created_at
        self.assignee_candidates = assignee_candidates
        self.language_owner = language_owner
        self.bot_advice = []
        self.target_readme_tag = ''
        self.readme_link = ''
        self.default_readme_tag = ''
        self.edit_content = ''
        self.package_name = ''
        self.target_date = ''
        self.date_from_target = 0
        self.is_open = True
        self.issue_title = issue_package.issue.title.split(": ", 1)[-1]
        self.full_issue_title = issue_package.issue.title
        self.spec_repo = Path(os.getenv('SPEC_REPO'))
        self.typespec_json = Path(os.getenv('TYPESPEC_JSON'))
        self.language_name = "common"
        self.request_repo = request_repo

    @property
    def for_typespec(self) -> bool:
        with open(str(self.typespec_json), "r") as file:
            data = json.load(file)
        return self.package_name in data.get(self.language_name, [])

    def has_label(self, label: str) -> bool:
        return label in self.issue_package.labels_name

    @property
    def created_date_format(self) -> str:
        return str(date.fromtimestamp(self.issue_package.issue.created_at.timestamp()).strftime('%m-%d'))

    @property
    def target_date_format(self) -> str:
        try:
            return str(datetime.strptime(self.target_date, "%Y-%m-%d").strftime('%m-%d'))
        except:
            return str(self.target_date)

    def get_issue_body(self) -> List[str]:
        return [i for i in self.issue_package.issue.body.split("\n") if i]

    def handle_link_contains_commit(self, link: str) -> str:
        if 'commit' in link:
            commit_sha = link.split('commit/')[-1]
            commit = self.issue_package.rest_repo.get_commit(commit_sha)
            link = commit.files[0].blob_url
            link = re.sub('blob/(.*?)/specification', 'blob/main/specification', link)
        return link

    def comment(self, message: str) -> None:
        self.issue_package.issue.create_comment(message)

    # get "workloads/resource-manager" from "workloads/resource-manager/Microsoft.Workloads/stable/2023-04-01/operations.json"
    def get_valid_relative_readme_folder(self, readme_folder: str) -> str:
        folder = Path(Path(readme_folder).as_posix().strip("/"))
        while "resource-manager" in str(folder):
            if Path(self.spec_repo, folder, "readme.md").exists():
                return folder.as_posix()
            folder = folder.parent

        return folder.as_posix()

    def get_readme_from_pr_link(self, link: str) -> str:
        pr_number = int(link.replace(f"{_SWAGGER_PULL}/", "").split('/')[0])

        # Get Readme link
        pr_info = self.issue_package.rest_repo.get_pull(number=pr_number)
        pk_url_name = set()
        for pr_changed_file in pr_info.get_files():
            contents_url = urllib.parse.unquote(pr_changed_file.contents_url)
            if '/resource-manager' not in contents_url:
                continue
            try:
                pk_url_name.add(self.get_valid_relative_readme_folder(contents_url.split('/specification')[1]))
            except Exception as e:
                continue
        readme_link = [f'{_SWAGGER_URL}/{item}' for item in pk_url_name]
        if len(readme_link) > 1:
            multi_link = ', '.join(readme_link)
            pr = f"{_SWAGGER_PULL}/{pr_number}"
            self.comment(
                f'Hi, @{self.assignee}, by parsing {pr}, there are multi service link: {multi_link}. Please decide which one is the right.')
            self.add_label(MULTI_LINK_LABEL)
            raise Exception(f'multi link in "{pr}"')

        return readme_link[0]

    def get_readme_link(self, origin_link: str):
        # check whether link is valid
        if 'azure-rest-api-specs' not in origin_link:
            self.comment(f'Hi, @{self.owner}, "{origin_link}" is not valid link. Please follow [doc]'
                         f'(https://github.com/Azure/azure-rest-api-specs/blob/main/documentation/release-request/'
                         f'rules-for-release-request.md#2-link-to-pr-or-spec-if-pr-unavailable) to provide valid link like '
                         f'"https://github.com/Azure/azure-rest-api-specs/pull/16750" or '
                         f'"https://github.com/Azure/azure-rest-api-specs/tree/main/'
                         f'specification/network/resource-manager"')
            raise Exception('Invalid link!')
        elif 'azure-rest-api-specs-pr' in origin_link:
            self.comment(f'Hi @{self.owner}, only [Azure/azure-rest-api-specs](https://github.com/Azure/'
                         f'azure-rest-api-specs) is permitted to publish SDK, [Azure/azure-rest-api-specs-pr]'
                         f'(https://github.com/Azure/azure-rest-api-specs-pr) is not permitted. '
                         f'Please paste valid link!')
            raise Exception('Invalid link from private repo')

        # change commit link to pull json link(i.e. https://github.com/Azure/azure-rest-api-specs/
        # commit/77f5d3b5d2#diff-708c2fb)
        link = self.handle_link_contains_commit(origin_link)

        # if link is a pr, it can get both pakeage name and readme link.
        if 'pull' in link:
            self.readme_link = self.get_readme_from_pr_link(link)
        # if link is a url(i.e. https://github.com/Azure/azure-rest-api-specs/blob/main/specification/
        # xxx/resource-manager/readme.md)
        elif '/resource-manager' not in link:
            # (i.e. https://github.com/Azure/azure-rest-api-specs/tree/main/specification/xxxx)
            self.readme_link = link + '/resource-manager'
        else:
            relative_readme_folder = self.get_valid_relative_readme_folder(link.split('/specification')[1])
            self.readme_link = f"{_SWAGGER_URL}/{relative_readme_folder}"

    @property
    def readme_local(self) -> str:
        return str(Path(self.spec_repo, self.readme_link.split('specification/')[1]))
    
    def local_file(self, name: str = "readme.md") -> Path:
        return Path(self.readme_local, name)

    def get_local_file_content(self, name: str = "readme.md") -> str:
        with open(Path(self.readme_local, name), 'r', encoding='utf-8') as f:
            return f.read()

    def get_default_readme_tag(self) -> None:
        contents = self.get_local_file_content()
        pattern_tag = re.compile(r'tag: package-[\w+-.]+')
        self.default_readme_tag = pattern_tag.search(contents).group().split(':')[-1].strip()

    def get_edit_content(self) -> None:
        self.edit_content = f'\n{self.readme_link.replace("/readme.md", "")}'

    def edit_issue_body(self) -> None:
        self.get_edit_content()
        issue_body_list = [i for i in self.issue_package.issue.body.split("\n") if i]
        issue_body_list.insert(0, self.edit_content)
        issue_body_up = ''
        # solve format problems
        for raw in issue_body_list:
            if raw == '---\r' or raw == '---':
                issue_body_up += '\n'
            issue_body_up += raw + '\n'
        self.issue_package.issue.edit(body=issue_body_up)

    def check_tag_consistency(self) -> None:
        self.target_readme_tag = self.target_readme_tag.replace('tag-', '')
        if self.default_readme_tag != self.target_readme_tag:
            self.add_label(INCONSISTENT_TAG)
            if "typespec" not in self.full_issue_title.lower():
                self.comment(f'Hi, @{self.owner}, according to [rule](https://github.com/Azure/azure-rest-api-specs/blob/'
                            f'main/documentation/release-request/rules-for-release-request.md#3-readme-tag-to-be-released),'
                            f' your **Readme Tag** is `{self.target_readme_tag}`, but in [readme.md]({self.readme_link}#basic-information) '
                            f'it is still `{self.default_readme_tag}`, please modify the readme.md or your '
                            f'**Readme Tag** above ')

    def get_package_name(self) -> None:
        issue_body_list = self.get_issue_body()
        for line in issue_body_list:
            if line.strip('\r\n ').startswith('package-name:'):
                self.package_name = line.split(':')[-1].strip('\r\n ')
                break

    def auto_parse(self) -> None:
        if self.has_label(AUTO_PARSE_LABEL):
            self.get_package_name()
            return

        self.add_label(AUTO_PARSE_LABEL)
        issue_body_list = self.get_issue_body()

        # Get the origin link and readme tag in issue body
        origin_link, target_readme_tag = get_origin_link_and_tag(issue_body_list)
        self.target_readme_tag = target_readme_tag if not self.target_readme_tag else self.target_readme_tag

        # get readme_link
        self.get_readme_link(origin_link)

        # get default tag with readme_link
        self.get_default_readme_tag()

        self.check_tag_consistency()

        self.edit_issue_body()

    def add_label(self, label: str) -> None:
        if not self.has_label(label):
            self.issue_package.issue.add_to_labels(label)
            self.issue_package.labels_name.add(label)

    def update_assignee(self, assignee_to_del: str, assignee_to_add: str) -> None:
        if assignee_to_del:
            self.issue_package.issue.remove_from_assignees(assignee_to_del)
        self.issue_package.issue.add_to_assignees(assignee_to_add)
        self.assignee = assignee_to_add

    def log(self, message: str) -> None:
        _LOG.info(f'issue {self.issue_package.issue.number}: {message}')

    def update_issue_instance(self) -> None:
        self.issue_package.issue = self.request_repo.get_issue(self.issue_package.issue.number)

    def auto_assign_policy(self) -> str:
        assignees = list(self.assignee_candidates)
        random_idx = randint(0, len(assignees) - 1) if len(assignees) > 1 else 0
        return assignees[random_idx]

    def auto_assign(self) -> None:
        if self.has_label(AUTO_ASSIGN_LABEL):
            self.update_issue_instance()
            return
        # assign averagely
        assignee = self.auto_assign_policy()

        # update assignee
        if self.assignee != assignee:
            self.log(f'remove assignee "{self.issue_package.issue.assignee}" and add "{assignee}"')
            self.assignee = assignee
            self.update_issue_instance()
            self.update_assignee(self.issue_package.issue.assignee, assignee)
        else:
            self.update_issue_instance()
        self.add_label(AUTO_ASSIGN_LABEL)

    def new_issue_policy(self):
        new_issue_advice = 'new issue.'
        if self.issue_package.issue.comments == 0:
            self.bot_advice.append(new_issue_advice)
        else:
            # issue that no comment from language owner will also be treated as new issue
            comment_from_owner = set(comment.user.login for comment in self.issue_package.issue.get_comments()
                                     if comment.user.login in self.language_owner)
            if not comment_from_owner:
                self.bot_advice.append(new_issue_advice)

    def new_comment_policy(self):
        if self.issue_package.issue.comments == 0:
            return
        comments = [(comment.updated_at.timestamp(), comment.user.login) for comment in
                    self.issue_package.issue.get_comments()]
        comments.sort()
        try:
            latest_comments = comments[-1][1]
            if latest_comments not in self.language_owner:
                self.bot_advice.append('new comment.')
        except Exception:
            self.log('Error happened when getting latest comment.')

    def multi_link_policy(self):
        if self.has_label(MULTI_LINK_LABEL):
            self.bot_advice.append('multi readme link!')

    def inconsistent_tag_policy(self):
        if self.has_label(INCONSISTENT_TAG):
            self.bot_advice.append('Attention to inconsistent tag.')

    def remind_logic(self) -> bool:
        return abs(self.date_from_target) <= 2

    def print_date_from_target_date(self) -> str:
        return str(self.date_from_target) if self.remind_logic() else ''

    def date_remind_policy(self):
        if self.remind_logic():
            self.bot_advice.append('close to release date.')

    def hint_policy(self):
        for item in _HINTS:
            if self.has_label(item):
                self.bot_advice.append(f"{item}.")

    def typespec_policy(self):
        if self.for_typespec:
            self.add_label(TYPESPEC_LABEL)

    def auto_bot_advice(self):
        self.new_issue_policy()
        self.typespec_policy()
        self.new_comment_policy()
        self.multi_link_policy()
        self.date_remind_policy()
        self.inconsistent_tag_policy()
        self.hint_policy()

    def get_target_date(self):
        body = self.get_issue_body()
        try:
            try:
                self.target_date = [re.compile(r"\d{4}-\d{1,2}-\d{1,2}").findall(l)[0] for l in body if 'Target release date' in l][0]
            except Exception:
                try:
                    self.target_date = [re.compile(r"\d{1,2}/\d{1,2}/\d{4}").findall(l)[0] for l in body if 'Target release date' in l][0]
                    self.target_date = datetime.strptime(self.target_date, "%m/%d/%Y").strftime('%Y-%m-%d')
                except Exception:
                    self.target_date = [re.compile(r"\d{1,2}/\d{1,2}/\d{4}").findall(l)[0] for l in body if 'Target release date' in l][0]
                    self.target_date = datetime.strptime(self.target_date, "%d/%m/%Y").strftime('%Y-%m-%d')

            self.date_from_target = int((time.mktime(time.strptime(self.target_date, '%Y-%m-%d')) - time.time()) / 3600 / 24)
        except Exception:
            self.target_date = 'fail to get.'
            self.date_from_target = 1000  # make a ridiculous data to remind failure when error happens

    def update_owner(self) -> None:
        issue_body = self.get_issue_body()
        for line in issue_body:
            if "Requested by" in line:
                self.owner = line.split('@')[-1].strip(', *\r\n')
                break

    def run(self) -> None:
        # common part(don't change the order)
        self.update_owner()
        self.auto_assign()  # necessary flow
        self.auto_parse()  # necessary flow
        self.get_target_date()
        self.auto_bot_advice()  # make sure this is the last step


class Common:
    """ The class defines some function for all languages to reference
    issues_package = None  # issues that need to handle
    request_repo  # request repo instance generated by token
    assignee_candidates = {}  # assignee candidates who will be assigned to handle issue
    language_owner = {}  # language owner who may handle issue
    result = []
    file_out_name = ''  # file that storages issue status
    """

    def __init__(self, issues_package: List[IssuePackage], language_owner: Set[str],
                 sdk_assignees: Set[str], assignee_token=_ASSIGNEE_TOKEN):
        self.issues_package = issues_package
        self.language_owner = language_owner | sdk_assignees
        self.assignee_candidates = sdk_assignees
        # arguments add to language.md
        self.file_out_name = 'common.md'
        self.target_release_date = ''
        self.date_from_target = ''
        self.package_name = ''
        self.result = []
        self.request_repo = Github(assignee_token).get_repo(REQUEST_REPO)
        self.issue_process_function = IssueProcess

    @staticmethod
    def for_test():
        return bool(os.getenv("TEST_ISSUE_NUMBER"))

    def log_error(self, message: str) -> None:
        _LOG.error(message)

    def output(self):
        with open(self.file_out_name, 'w') as file_out:
            file_out.write('| id | issue | author | package | assignee | bot advice | created date of issue | target release date | date from target |\n')
            file_out.write('| ------ | ------ | ------ | ------ | ------ | ------ | ------ | ------ | :-----: |\n')
            for idx, item in enumerate(self.result):
                try:
                    if item.is_open:
                        item_status = Common.output_md(idx + 1, item)
                        file_out.write(item_status)
                except Exception as e:
                    self.log_error(f'Error happened during output result of handled issue {item.issue_package.issue.number}: {e}')

    @staticmethod
    def output_md(idx: int, item: IssueProcess):
        return '| {} | [#{}]({}) | {} | {} | {} | {} | {} | {} | {} |\n'.format(
            idx,
            item.issue_package.issue.html_url.split('/')[-1],
            item.issue_package.issue.html_url,
            item.owner,
            item.package_name,
            item.assignee,
            ' '.join(item.bot_advice),
            item.created_date_format,
            item.target_date_format,
            item.print_date_from_target_date()
        )

    def proc_issue(self):
        for item in self.issues_package:
            issue = self.issue_process_function(item, self.request_repo, self.assignee_candidates,
                                                self.language_owner)

            try:
                issue.run()
            except Exception as e:
                self.log_error(f'Error happened during handling issue {item.issue.number}: {e}')
            self.result.append(issue)

    def run(self):
        self.proc_issue()
        self.output()


def common_process(issues: List[IssuePackage]) -> Common:
    return Common(issues,  _LANGUAGE_OWNER, _LANGUAGE_OWNER)



# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
from io import IOBase
from typing import Any, Callable, Dict, IO, Optional, TypeVar, Union, overload

from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    ResourceNotModifiedError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.pipeline.transport import HttpResponse
from azure.core.rest import HttpRequest
from azure.core.tracing.decorator import distributed_trace
from azure.core.utils import case_insensitive_dict
from azure.mgmt.core.exceptions import ARMErrorFormat

from .. import models as _models
from .._serialization import Serializer
from .._vendor import DevHubMgmtClientMixinABC, _convert_request, _format_url_section

T = TypeVar("T")
ClsType = Optional[Callable[[PipelineResponse[HttpRequest, HttpResponse], T, Dict[str, Any]], Any]]

_SERIALIZER = Serializer()
_SERIALIZER.client_side_validation = False


def build_git_hub_o_auth_request(location: str, subscription_id: str, **kwargs: Any) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2022-10-11-preview"))
    content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url",
        "/subscriptions/{subscriptionId}/providers/Microsoft.DevHub/locations/{location}/githuboauth/default/getGitHubOAuthInfo",
    )  # pylint: disable=line-too-long
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str", min_length=1),
        "location": _SERIALIZER.url("location", location, "str", min_length=1),
    }

    _url: str = _format_url_section(_url, **path_format_arguments)  # type: ignore

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")

    # Construct headers
    if content_type is not None:
        _headers["Content-Type"] = _SERIALIZER.header("content_type", content_type, "str")
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="POST", url=_url, params=_params, headers=_headers, **kwargs)


def build_git_hub_o_auth_callback_request(
    location: str, subscription_id: str, *, code: str, state: str, **kwargs: Any
) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2022-10-11-preview"))
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url",
        "/subscriptions/{subscriptionId}/providers/Microsoft.DevHub/locations/{location}/githuboauth/default",
    )  # pylint: disable=line-too-long
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str", min_length=1),
        "location": _SERIALIZER.url("location", location, "str", min_length=1),
    }

    _url: str = _format_url_section(_url, **path_format_arguments)  # type: ignore

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")
    _params["code"] = _SERIALIZER.query("code", code, "str")
    _params["state"] = _SERIALIZER.query("state", state, "str")

    # Construct headers
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="GET", url=_url, params=_params, headers=_headers, **kwargs)


def build_list_git_hub_o_auth_request(location: str, subscription_id: str, **kwargs: Any) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2022-10-11-preview"))
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url", "/subscriptions/{subscriptionId}/providers/Microsoft.DevHub/locations/{location}/githuboauth"
    )  # pylint: disable=line-too-long
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str", min_length=1),
        "location": _SERIALIZER.url("location", location, "str", min_length=1),
    }

    _url: str = _format_url_section(_url, **path_format_arguments)  # type: ignore

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")

    # Construct headers
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="GET", url=_url, params=_params, headers=_headers, **kwargs)


def build_generate_preview_artifacts_request(location: str, subscription_id: str, **kwargs: Any) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2022-10-11-preview"))
    content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url",
        "/subscriptions/{subscriptionId}/providers/Microsoft.DevHub/locations/{location}/generatePreviewArtifacts",
    )  # pylint: disable=line-too-long
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str", min_length=1),
        "location": _SERIALIZER.url("location", location, "str", min_length=1),
    }

    _url: str = _format_url_section(_url, **path_format_arguments)  # type: ignore

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")

    # Construct headers
    if content_type is not None:
        _headers["Content-Type"] = _SERIALIZER.header("content_type", content_type, "str")
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="POST", url=_url, params=_params, headers=_headers, **kwargs)


class DevHubMgmtClientOperationsMixin(DevHubMgmtClientMixinABC):
    @overload
    def git_hub_o_auth(
        self,
        location: str,
        parameters: Optional[_models.GitHubOAuthCallRequest] = None,
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> _models.GitHubOAuthInfoResponse:
        """Gets GitHubOAuth info used to authenticate users with the Developer Hub GitHub App.

        Gets GitHubOAuth info used to authenticate users with the Developer Hub GitHub App.

        :param location: The name of Azure region. Required.
        :type location: str
        :param parameters: Default value is None.
        :type parameters: ~azure.mgmt.devhub.models.GitHubOAuthCallRequest
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GitHubOAuthInfoResponse or the result of cls(response)
        :rtype: ~azure.mgmt.devhub.models.GitHubOAuthInfoResponse
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    def git_hub_o_auth(
        self, location: str, parameters: Optional[IO] = None, *, content_type: str = "application/json", **kwargs: Any
    ) -> _models.GitHubOAuthInfoResponse:
        """Gets GitHubOAuth info used to authenticate users with the Developer Hub GitHub App.

        Gets GitHubOAuth info used to authenticate users with the Developer Hub GitHub App.

        :param location: The name of Azure region. Required.
        :type location: str
        :param parameters: Default value is None.
        :type parameters: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GitHubOAuthInfoResponse or the result of cls(response)
        :rtype: ~azure.mgmt.devhub.models.GitHubOAuthInfoResponse
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace
    def git_hub_o_auth(
        self, location: str, parameters: Optional[Union[_models.GitHubOAuthCallRequest, IO]] = None, **kwargs: Any
    ) -> _models.GitHubOAuthInfoResponse:
        """Gets GitHubOAuth info used to authenticate users with the Developer Hub GitHub App.

        Gets GitHubOAuth info used to authenticate users with the Developer Hub GitHub App.

        :param location: The name of Azure region. Required.
        :type location: str
        :param parameters: Is either a GitHubOAuthCallRequest type or a IO type. Default value is None.
        :type parameters: ~azure.mgmt.devhub.models.GitHubOAuthCallRequest or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GitHubOAuthInfoResponse or the result of cls(response)
        :rtype: ~azure.mgmt.devhub.models.GitHubOAuthInfoResponse
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", self._config.api_version))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.GitHubOAuthInfoResponse] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(parameters, (IOBase, bytes)):
            _content = parameters
        else:
            if parameters is not None:
                _json = self._serialize.body(parameters, "GitHubOAuthCallRequest")
            else:
                _json = None

        request = build_git_hub_o_auth_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self.git_hub_o_auth.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.ErrorResponse, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("GitHubOAuthInfoResponse", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    git_hub_o_auth.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.DevHub/locations/{location}/githuboauth/default/getGitHubOAuthInfo"
    }

    @distributed_trace
    def git_hub_o_auth_callback(
        self, location: str, code: str, state: str, **kwargs: Any
    ) -> _models.GitHubOAuthResponse:
        """Callback URL to hit once authenticated with GitHub App to have the service store the OAuth
        token.

        Callback URL to hit once authenticated with GitHub App to have the service store the OAuth
        token.

        :param location: The name of Azure region. Required.
        :type location: str
        :param code: The code response from authenticating the GitHub App. Required.
        :type code: str
        :param state: The state response from authenticating the GitHub App. Required.
        :type state: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GitHubOAuthResponse or the result of cls(response)
        :rtype: ~azure.mgmt.devhub.models.GitHubOAuthResponse
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", self._config.api_version))
        cls: ClsType[_models.GitHubOAuthResponse] = kwargs.pop("cls", None)

        request = build_git_hub_o_auth_callback_request(
            location=location,
            subscription_id=self._config.subscription_id,
            code=code,
            state=state,
            api_version=api_version,
            template_url=self.git_hub_o_auth_callback.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.ErrorResponse, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("GitHubOAuthResponse", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    git_hub_o_auth_callback.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.DevHub/locations/{location}/githuboauth/default"
    }

    @distributed_trace
    def list_git_hub_o_auth(self, location: str, **kwargs: Any) -> _models.GitHubOAuthListResponse:
        """Callback URL to hit once authenticated with GitHub App to have the service store the OAuth
        token.

        Callback URL to hit once authenticated with GitHub App to have the service store the OAuth
        token.

        :param location: The name of Azure region. Required.
        :type location: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GitHubOAuthListResponse or the result of cls(response)
        :rtype: ~azure.mgmt.devhub.models.GitHubOAuthListResponse
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", self._config.api_version))
        cls: ClsType[_models.GitHubOAuthListResponse] = kwargs.pop("cls", None)

        request = build_list_git_hub_o_auth_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            template_url=self.list_git_hub_o_auth.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.ErrorResponse, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("GitHubOAuthListResponse", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    list_git_hub_o_auth.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.DevHub/locations/{location}/githuboauth"
    }

    @overload
    def generate_preview_artifacts(
        self,
        location: str,
        parameters: _models.ArtifactGenerationProperties,
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> Dict[str, str]:
        """Generate preview dockerfile and manifests.

        Generate preview dockerfile and manifests.

        :param location: The name of Azure region. Required.
        :type location: str
        :param parameters: Required.
        :type parameters: ~azure.mgmt.devhub.models.ArtifactGenerationProperties
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: dict mapping str to str or the result of cls(response)
        :rtype: dict[str, str]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    def generate_preview_artifacts(
        self, location: str, parameters: IO, *, content_type: str = "application/json", **kwargs: Any
    ) -> Dict[str, str]:
        """Generate preview dockerfile and manifests.

        Generate preview dockerfile and manifests.

        :param location: The name of Azure region. Required.
        :type location: str
        :param parameters: Required.
        :type parameters: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: dict mapping str to str or the result of cls(response)
        :rtype: dict[str, str]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace
    def generate_preview_artifacts(
        self, location: str, parameters: Union[_models.ArtifactGenerationProperties, IO], **kwargs: Any
    ) -> Dict[str, str]:
        """Generate preview dockerfile and manifests.

        Generate preview dockerfile and manifests.

        :param location: The name of Azure region. Required.
        :type location: str
        :param parameters: Is either a ArtifactGenerationProperties type or a IO type. Required.
        :type parameters: ~azure.mgmt.devhub.models.ArtifactGenerationProperties or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: dict mapping str to str or the result of cls(response)
        :rtype: dict[str, str]
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", self._config.api_version))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[Dict[str, str]] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(parameters, (IOBase, bytes)):
            _content = parameters
        else:
            _json = self._serialize.body(parameters, "ArtifactGenerationProperties")

        request = build_generate_preview_artifacts_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self.generate_preview_artifacts.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.ErrorResponse, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("{str}", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    generate_preview_artifacts.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.DevHub/locations/{location}/generatePreviewArtifacts"
    }



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.appconfiguration import AppConfigurationManagementClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-appconfiguration
# USAGE
    python configuration_stores_list_keys.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = AppConfigurationManagementClient(
        credential=DefaultAzureCredential(),
        subscription_id="c80fb759-c965-4c6a-9110-9b2b2d038882",
    )

    response = client.configuration_stores.list_keys(
        resource_group_name="myResourceGroup",
        config_store_name="contoso",
    )
    for item in response:
        print(item)


# x-ms-original-file: specification/appconfiguration/resource-manager/Microsoft.AppConfiguration/stable/2024-05-01/examples/ConfigurationStoresListKeys.json
if __name__ == "__main__":
    main()



# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
from typing import TYPE_CHECKING

from msrest import Serializer

from azure.core.exceptions import ClientAuthenticationError, HttpResponseError, ResourceExistsError, ResourceNotFoundError, map_error
from azure.core.pipeline import PipelineResponse
from azure.core.pipeline.transport import HttpResponse
from azure.core.rest import HttpRequest
from azure.core.tracing.decorator import distributed_trace

from .. import models as _models
from .._vendor import _convert_request

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from typing import Any, Callable, Dict, Optional, TypeVar
    T = TypeVar('T')
    ClsType = Optional[Callable[[PipelineResponse[HttpRequest, HttpResponse], T, Dict[str, Any]], Any]]

_SERIALIZER = Serializer()
_SERIALIZER.client_side_validation = False
# fmt: off

def build_query_twins_request(
    **kwargs  # type: Any
):
    # type: (...) -> HttpRequest
    api_version = kwargs.pop('api_version', "2022-05-31")  # type: str
    content_type = kwargs.pop('content_type', None)  # type: Optional[str]
    traceparent = kwargs.pop('traceparent', None)  # type: Optional[str]
    tracestate = kwargs.pop('tracestate', None)  # type: Optional[str]
    max_items_per_page = kwargs.pop('max_items_per_page', None)  # type: Optional[int]

    accept = "application/json"
    # Construct URL
    _url = kwargs.pop("template_url", "/query")

    # Construct parameters
    _query_parameters = kwargs.pop("params", {})  # type: Dict[str, Any]
    _query_parameters['api-version'] = _SERIALIZER.query("api_version", api_version, 'str')

    # Construct headers
    _header_parameters = kwargs.pop("headers", {})  # type: Dict[str, Any]
    if traceparent is not None:
        _header_parameters['traceparent'] = _SERIALIZER.header("traceparent", traceparent, 'str')
    if tracestate is not None:
        _header_parameters['tracestate'] = _SERIALIZER.header("tracestate", tracestate, 'str')
    if max_items_per_page is not None:
        _header_parameters['max-items-per-page'] = _SERIALIZER.header("max_items_per_page", max_items_per_page, 'int')
    if content_type is not None:
        _header_parameters['Content-Type'] = _SERIALIZER.header("content_type", content_type, 'str')
    _header_parameters['Accept'] = _SERIALIZER.header("accept", accept, 'str')

    return HttpRequest(
        method="POST",
        url=_url,
        params=_query_parameters,
        headers=_header_parameters,
        **kwargs
    )

# fmt: on
class QueryOperations(object):
    """
    .. warning::
        **DO NOT** instantiate this class directly.

        Instead, you should access the following operations through
        :class:`~azure.digitaltwins.core.AzureDigitalTwinsAPI`'s
        :attr:`query` attribute.
    """

    models = _models

    def __init__(self, *args, **kwargs):
        args = list(args)
        self._client = args.pop(0) if args else kwargs.pop("client")
        self._config = args.pop(0) if args else kwargs.pop("config")
        self._serialize = args.pop(0) if args else kwargs.pop("serializer")
        self._deserialize = args.pop(0) if args else kwargs.pop("deserializer")


    @distributed_trace
    def query_twins(
        self,
        query_specification,  # type: "_models.QuerySpecification"
        query_twins_options=None,  # type: Optional["_models.QueryTwinsOptions"]
        **kwargs  # type: Any
    ):
        # type: (...) -> "_models.QueryResult"
        """Executes a query that allows traversing relationships and filtering by property values.
        Status codes:


        * 200 OK
        * 400 Bad Request

          * BadRequest - The continuation token is invalid.
          * SqlQueryError - The query contains some errors.
          * TimeoutError - The query execution timed out after 60 seconds. Try simplifying the query or
        adding conditions to reduce the result size.
          * 429 Too Many Requests
          * QuotaReachedError - The maximum query rate limit has been reached.

        :param query_specification: The query specification to execute.
        :type query_specification: ~azure.digitaltwins.core.models.QuerySpecification
        :param query_twins_options: Parameter group. Default value is None.
        :type query_twins_options: ~azure.digitaltwins.core.models.QueryTwinsOptions
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: QueryResult, or the result of cls(response)
        :rtype: ~azure.digitaltwins.core.models.QueryResult
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop('cls', None)  # type: ClsType["_models.QueryResult"]
        error_map = {
            401: ClientAuthenticationError, 404: ResourceNotFoundError, 409: ResourceExistsError
        }
        error_map.update(kwargs.pop('error_map', {}))

        api_version = kwargs.pop('api_version', "2022-05-31")  # type: str
        content_type = kwargs.pop('content_type', "application/json")  # type: Optional[str]

        _traceparent = None
        _tracestate = None
        _max_items_per_page = None
        if query_twins_options is not None:
            _traceparent = query_twins_options.traceparent
            _tracestate = query_twins_options.tracestate
            _max_items_per_page = query_twins_options.max_items_per_page
        _json = self._serialize.body(query_specification, 'QuerySpecification')

        request = build_query_twins_request(
            api_version=api_version,
            content_type=content_type,
            json=_json,
            traceparent=_traceparent,
            tracestate=_tracestate,
            max_items_per_page=_max_items_per_page,
            template_url=self.query_twins.metadata['url'],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = self._client._pipeline.run(  # pylint: disable=protected-access
            request,
            stream=False,
            **kwargs
        )
        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.ErrorResponse, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        response_headers = {}
        response_headers['query-charge']=self._deserialize('float', response.headers.get('query-charge'))

        deserialized = self._deserialize('QueryResult', pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, response_headers)

        return deserialized

    query_twins.metadata = {'url': "/query"}  # type: ignore




# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 30
# Methods Covered : 30
# Examples Total  : 20
# Examples Tested : 20
# Coverage %      : 67
# ----------------------

# Current Operation Coverage:
#   OpenShiftManagedClusters: 0/6 (only one preview version, so needn't test)
#   ContainerServices: 0/6 (the interface is going to retire, so needn't test)
#   Operations: 1/1
#   ManagedClusters: 13/17
#   AgentPools: 4/6
#   PrivateEndpointConnections: 0/4
#   PrivateLinkResourcesOperations: 1/1
#   ResolvePrivateLinkServiceIdOperations : 1/1

import unittest
import pytest
import time

import azure.mgmt.containerservice
from devtools_testutils import AzureMgmtRecordedTestCase, ResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


class TestMgmtContainerServiceClient(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.containerservice.ContainerServiceClient)

    @pytest.mark.skip("hard to test")
    @ResourceGroupPreparer()
    def test_managed_clusters(self, resource_group):
        CLIENT_ID = getattr(self.settings, "CLIENT_ID", "123")
        CLIENT_SECRET = getattr(self.settings, "CLIENT_SECRET", "123")
        RESOURCE_GROUP = resource_group.name
        RESOURCE_NAME = "7"

        # 1
        # Create sample managed cluster
        BODY = {
            "dns_prefix": "akspythonsdk",
            "agent_pool_profiles": [
                {
                    "name": "aksagent",
                    "count": 1,
                    "vm_size": "Standard_DS2_v2",
                    "max_pods": 110,
                    "min_count": 1,
                    "max_count": 100,
                    "os_type": "Linux",
                    "type": "VirtualMachineScaleSets",
                    "enable_auto_scaling": True,
                    "mode": "System",
                }
            ],
            "service_principal_profile": {"client_id": CLIENT_ID, "secret": CLIENT_SECRET},
            "location": AZURE_LOCATION,
        }
        for i in range(10):
            try:
                result = self.mgmt_client.managed_clusters.begin_create_or_update(
                    resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME, parameters=BODY
                )
                result.result()
            except azure.core.exceptions.ResourceExistsError:
                time.sleep(30)
            else:
                break
        # 2
        self.mgmt_client.managed_clusters.list_cluster_admin_credentials(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME
        )
        # 3
        self.mgmt_client.managed_clusters.list_cluster_user_credentials(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME
        )
        # 4
        self.mgmt_client.managed_clusters.get_upgrade_profile(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME
        )
        # # 5
        # result = self.mgmt_client.managed_clusters.begin_stop(resource_group_name=RESOURCE_GROUP,
        #                                                       resource_name=RESOURCE_NAME)
        # result.result()
        # # 6
        # result = self.mgmt_client.managed_clusters.begin_start(resource_group_name=RESOURCE_GROUP,
        #                                                        resource_name=RESOURCE_NAME)
        # result.result()
        # 7
        self.mgmt_client.managed_clusters.get(resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME)
        # 8
        self.mgmt_client.managed_clusters.list_by_resource_group(resource_group_name=RESOURCE_GROUP)
        # 9
        self.mgmt_client.managed_clusters.list()
        # # 10
        # result = self.mgmt_client.managed_clusters.begin_rotate_cluster_certificates(resource_group_name=RESOURCE_GROUP,
        #                                                                              resource_name=RESOURCE_NAME)
        result.result()
        # 11
        BODY = {"tags": {"tier": "testing", "archv3": ""}}
        result = self.mgmt_client.managed_clusters.begin_update_tags(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME, parameters=BODY
        )
        result.result()
        # 12
        self.mgmt_client.managed_clusters.list_cluster_monitoring_user_credentials(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME
        )
        # 13
        result = self.mgmt_client.managed_clusters.begin_delete(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME
        )
        result.result()

    @pytest.mark.skip("duplicated testcase")
    @ResourceGroupPreparer()
    @recorded_by_proxy
    def test_operations(self):
        result = list(self.mgmt_client.operations.list())
        for item in result:
            print(item.as_dict())

    @pytest.mark.skip("hard to test")
    @ResourceGroupPreparer()
    def test_privateLinkResources(self, resource_group):
        CLIENT_ID = getattr(self.settings, "CLIENT_ID", "123")
        CLIENT_SECRET = getattr(self.settings, "CLIENT_SECRET", "123")
        RESOURCE_GROUP = resource_group.name
        RESOURCE_NAME = "2"

        # Create sample managed cluster
        BODY = {
            "dns_prefix": "akspythonsdk",
            "agent_pool_profiles": [
                {
                    "name": "aksagent",
                    "count": 1,
                    "vm_size": "Standard_DS2_v2",
                    "max_pods": 110,
                    "min_count": 1,
                    "max_count": 100,
                    "os_type": "Linux",
                    "type": "VirtualMachineScaleSets",
                    "enable_auto_scaling": True,
                    "mode": "System",
                }
            ],
            "api_server_access_profile": {"enable_private_cluster": True},  # private cluster
            "service_principal_profile": {"client_id": CLIENT_ID, "secret": CLIENT_SECRET},
            "location": AZURE_LOCATION,
        }
        for i in range(10):
            try:
                result = self.mgmt_client.managed_clusters.begin_create_or_update(
                    resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME, parameters=BODY
                )
                result.result()
            except azure.core.exceptions.ResourceExistsError:
                time.sleep(30)
            else:
                break

        # 1
        self.mgmt_client.private_link_resources.list(resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME)

    @pytest.mark.skip("hard to test")
    @ResourceGroupPreparer()
    def test_resolvePrivateLinkServiceId(self, resource_group):
        CLIENT_ID = getattr(self.settings, "CLIENT_ID", "123")
        CLIENT_SECRET = getattr(self.settings, "CLIENT_SECRET", "123")
        RESOURCE_GROUP = resource_group.name
        RESOURCE_NAME = "3"

        # Create sample managed cluster
        BODY = {
            "dns_prefix": "akspythonsdk",
            "agent_pool_profiles": [
                {
                    "name": "aksagent",
                    "count": 1,
                    "vm_size": "Standard_DS2_v2",
                    "max_pods": 110,
                    "min_count": 1,
                    "max_count": 100,
                    "os_type": "Linux",
                    "type": "VirtualMachineScaleSets",
                    "enable_auto_scaling": True,
                    "mode": "System",
                }
            ],
            "api_server_access_profile": {"enable_private_cluster": True},  # private cluster
            "service_principal_profile": {"client_id": CLIENT_ID, "secret": CLIENT_SECRET},
            "location": AZURE_LOCATION,
        }
        for i in range(10):
            try:
                result = self.mgmt_client.managed_clusters.begin_create_or_update(
                    resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME, parameters=BODY
                )
                result.result()
            except azure.core.exceptions.ResourceExistsError:
                time.sleep(30)
            else:
                break

        # 1
        BODY = {"name": "testManagement"}
        self.mgmt_client.resolve_private_link_service_id.post(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME, parameters=BODY
        )

    @pytest.mark.skip("hard to test")
    @ResourceGroupPreparer()
    def test_agentPools(self, resource_group):
        CLIENT_ID = getattr(self.settings, "CLIENT_ID", "123")
        CLIENT_SECRET = getattr(self.settings, "CLIENT_SECRET", "123")
        RESOURCE_GROUP = resource_group.name
        RESOURCE_NAME = "4"
        AGENT_POOL_NAME = "aksagent"
        MODE = "System"
        VM_SIZE = "Standard_DS2_v2"

        # Create sample managed cluster
        BODY = {
            "dns_prefix": "akspythonsdk",
            "agent_pool_profiles": [
                {
                    "name": "aksagent",
                    "count": 1,
                    "vm_size": "Standard_DS2_v2",
                    "max_pods": 110,
                    "min_count": 1,
                    "max_count": 100,
                    "os_type": "Linux",
                    "type": "VirtualMachineScaleSets",
                    "enable_auto_scaling": True,
                    "mode": "System",
                }
            ],
            "service_principal_profile": {"client_id": CLIENT_ID, "secret": CLIENT_SECRET},
            "location": AZURE_LOCATION,
        }
        result = self.mgmt_client.managed_clusters.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME, parameters=BODY
        )
        result.result()

        # 1
        BODY = {
            "orchestrator_version": "",
            "count": "3",
            "vm_size": VM_SIZE,
            "os_type": "Linux",
            "type": "VirtualMachineScaleSets",
            "mode": MODE,
            "availability_zones": ["1", "2", "3"],
            # "scale_set_priority": "Regular",
            # "scale_set_eviction_policy": "Delete",
            "node_taints": [],
        }
        for i in range(10):
            try:
                result = self.mgmt_client.agent_pools.begin_create_or_update(
                    resource_group_name=RESOURCE_GROUP,
                    resource_name=RESOURCE_NAME,
                    agent_pool_name=AGENT_POOL_NAME,
                    parameters=BODY,
                )
                result = result.result()
            except azure.core.exceptions.ResourceExistsError:
                time.sleep(30)
            else:
                break

        # 2
        self.mgmt_client.agent_pools.get(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME, agent_pool_name=AGENT_POOL_NAME
        )
        # 3
        self.mgmt_client.agent_pools.get_available_agent_pool_versions(
            resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME
        )
        # 4
        self.mgmt_client.agent_pools.list(resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME)

        # result = self.mgmt_client.agent_pools.begin_delete(resource_group_name=RESOURCE_GROUP,
        #                                                    resource_name=RESOURCE_NAME, agent_pool_name=AGENT_POOL_NAME)
        # result = result.result()

        # self.mgmt_client.agent_pools.get_upgrade_profile(resource_group_name=RESOURCE_GROUP,
        #                                                  resource_name=RESOURCE_NAME, agent_pool_name=AGENT_POOL_NAME,
        #                                                  upgrade_profile_name=UPGRADE_PROFILE_NAME)

    # @ResourceGroupPreparer()
    # def test_privateEndpointConnections(self, resource_group):
    #     CLIENT_ID = self.settings.CLIENT_ID or "123"
    #     CLIENT_SECRET = self.settings.CLIENT_SECRET or "123"
    #     RESOURCE_GROUP = resource_group.name
    #     RESOURCE_NAME = "myResource"
    #     PRIVATE_ENDPOINT_CONNECTION_NAME = 'testPrivateEndPointConnectionName'
    #
    #     BODY = {
    #         "dns_prefix": "akspythonsdk",
    #         "agent_pool_profiles": [
    #             {
    #                 "name": "aksagent",
    #                 "count": 1,
    #                 "vm_size": "Standard_DS2_v2",
    #                 "max_pods": 110,
    #                 "min_count": 1,
    #                 "max_count": 100,
    #                 "os_type": "Linux",
    #                 "type": "VirtualMachineScaleSets",
    #                 "enable_auto_scaling": True,
    #                 "mode": "System",
    #             }
    #         ],
    #         "api_server_access_profile": {
    #             "enable_private_cluster": True  # private cluster
    #         },
    #         "service_principal_profile": {
    #             "client_id": CLIENT_ID,
    #             "secret": CLIENT_SECRET
    #         },
    #         "location": AZURE_LOCATION
    #     }
    #     result = self.mgmt_client.managed_clusters.begin_create_or_update(resource_group_name=RESOURCE_GROUP,
    #                                                                       resource_name=RESOURCE_NAME, parameters=BODY)
    #     result.result()
    #
    #     # 1
    #     BODY = {
    #         "private_link_service_connection_state": {
    #             "status": "Approved"
    #         }
    #     }
    #     self.mgmt_client.private_endpoint_connections.update(resource_group_name=RESOURCE_GROUP,
    #                                                          resource_name=RESOURCE_NAME,
    #                                                          private_endpoint_connection_name=PRIVATE_ENDPOINT_CONNECTION_NAME,
    #                                                          parameters=BODY)
    #
    #     # 2
    #     self.mgmt_client.private_endpoint_connections.get(resource_group_name=RESOURCE_GROUP,
    #                                                       resource_name=RESOURCE_NAME,
    #                                                       private_endpoint_connection_name=PRIVATE_ENDPOINT_CONNECTION_NAME)
    #
    #     # 3
    #     self.mgmt_client.private_endpoint_connections.list(resource_group_name=RESOURCE_GROUP,
    #                                                        resource_name=RESOURCE_NAME)
    #
    #     # 4
    #     result = self.mgmt_client.private_endpoint_connections.begin_delete(resource_group_name=RESOURCE_GROUP,
    #                                                                         resource_name=RESOURCE_NAME,
    #                                                                         private_endpoint_connection_name=PRIVATE_ENDPOINT_CONNECTION_NAME)
    #     result = result.result()

    # # the interface is going to retire, so needn't test
    # @ResourceGroupPreparer()
    # def test_containerServices(self, resource_group):
    #     CLIENT_ID = self.settings.CLIENT_ID or "123"
    #     CLIENT_SECRET = self.settings.CLIENT_SECRET or "123"
    #     RESOURCE_GROUP = resource_group.name
    #     CONTAINER_SERVICE_NAME = "myContainerService"
    #     KEYDATA = self.settings.KEYDATA  # git bash use 'cat ~/.ssh/id_rsa.pub'
    #
    #     # /ContainerServices/put/Create/Update Container Service[put]
    #
    #     BODY = {
    #         "location": AZURE_LOCATION,
    #         "agent_pool_profiles": [
    #             {
    #                 "name": "agentx",
    #                 "count": 1,
    #                 "vm_size": "Standard_DS2_v2",
    #                 "os_type": "Linux",
    #                 "dns_prefix": "agentdnsx"
    #             }
    #         ],
    #         "linux_profile": {
    #             "ssh": {
    #                 "public_keys": [
    #                     {
    #                         "key_data": KEYDATA
    #                     }
    #                 ]
    #             },
    #             "admin_username": "azureuser"
    #         },
    #         "master_profile": {
    #             "vm_size": "Standard_A3",
    #             "dns_prefix": "sdkmaster",
    #         },
    #         "orchestrator_profile": {
    #             "orchestrator_type": "DCOS"
    #         },
    #         # "address_space": {
    #         #     "address_prefixes": [
    #         #         "192.168.0.0/16"
    #         #         # "10.2.0.0/16"
    #         #     ]
    #         # },
    #         # "subnets": [
    #         #     {
    #         #         "properties": {
    #         #             "address_prefix": "192.168.0.0/24"
    #         #         },
    #         #         # "name": "clisubnet000005"
    #         #     }
    #         # ]
    #
    #     }
    #     # result = self.mgmt_client.container_services.begin_create_or_update(resource_group_name=RESOURCE_GROUP,
    #     #                                                                     container_service_name=CONTAINER_SERVICE_NAME,
    #     #                                                                     parameters=BODY)
    #     # result = result.result()
    #
    #     # /ContainerServices/get/Get Container Service[get]
    #
    #     # result = self.mgmt_client.container_services.get(resource_group_name=RESOURCE_GROUP,
    #     #                                                  container_service_name=CONTAINER_SERVICE_NAME)
    #
    #     # /ContainerServices/get/List Container Services by Resource Group[get]
    #
    #     result = self.mgmt_client.container_services.list_by_resource_group(resource_group_name=RESOURCE_GROUP)
    #
    #     # /ContainerServices/get/List Container Service Orchestrators[get]
    #
    #     result = self.mgmt_client.container_services.list_orchestrators()
    #
    #     # /ContainerServices/get/List Container Services[get]
    #
    #     result = self.mgmt_client.container_services.list()
    #
    #     # /ContainerServices/delete/Delete Container Service[delete]
    #
    #     # result = self.mgmt_client.container_services.begin_delete(resource_group_name=RESOURCE_GROUP, container_service_name=CONTAINER_SERVICE_NAME)
    #     # result = result.result()
    #
    # @ResourceGroupPreparer()
    # def test_OpenShiftManagedClusters(self, resource_group):
    #     SUBSCRIPTION_ID = self.settings.SUBSCRIPTION_ID
    #     TENANT_ID = self.settings.TENANT_ID
    #     CLIENT_ID = self.settings.CLIENT_ID or "123"
    #     CLIENT_SECRET = self.settings.CLIENT_SECRET or "123"
    #     RESOURCE_GROUP = resource_group.name
    #     RESOURCE_NAME = 't'
    #
    #     # /OpenShiftManagedClusters/put/Create/Update OpenShift Managed Cluster[put]
    #
    #     BODY = {
    #         "location": AZURE_LOCATION,
    #         "tags": {
    #             "tier": "production",
    #             "archv2": ""
    #         },
    #         "open_shift_version": "v3.11",
    #         "network_profile": {
    #             "vnet_cidr": "10.0.0.0/8"
    #         },
    #         "master_pool_profile": {
    #             "name": "master",
    #             "count": "3",
    #             "vm_size": "Standard_D4s_v3",
    #             "os_type": "Linux",
    #             "subnet_cidr": "10.0.0.0/24"
    #         },
    #         "agent_pool_profiles": [
    #             {
    #                 "name": "infra",
    #                 "role": "infra",
    #                 "count": 1,
    #                 "vm_size": "Standard_D4s_v3",
    #                 "os_type": "Linux",
    #                 "subnet_cidr": "10.0.0.0/24"
    #             },
    #             {
    #                 "name": "compute",
    #                 "role": "compute",
    #                 "count": 1,
    #                 "vm_size": "Standard_D4s_v3",
    #                 "os_type": "Linux",
    #                 "subnet_cidr": "10.0.0.0/24"
    #             }
    #         ],
    #         "router_profiles": [
    #             {
    #                 "name": "default"
    #             }
    #         ],
    #         "auth_profile": {
    #             "identity_providers": [
    #                 {
    #                     "name": "Azure AD",
    #                     "provider": {
    #                         "kind": "AADIdentityProvider",
    #                         "client_id": CLIENT_ID,
    #                         "secret": CLIENT_SECRET,
    #                         "tenant_id": TENANT_ID,
    #                         #   "customer_admin_group_id": "customerAdminGroupId"
    #                         #   "customer_admin_group_id": RESOURCE_GROUP
    #                     }
    #                 }
    #             ]
    #         }
    #     }
    #     result = self.mgmt_client.open_shift_managed_clusters.begin_create_or_update(resource_group_name=RESOURCE_GROUP,
    #                                                                                  resource_name=RESOURCE_NAME,
    #                                                                                  parameters=BODY)
    #     result = result.result()
    #
    #     # /OpenShiftManagedClusters/get/Get OpenShift Managed Cluster[get]
    #
    #     # result = self.mgmt_client.open_shift_managed_clusters.get(resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME)
    #
    #     # /OpenShiftManagedClusters/get/Get Managed Clusters by Resource Group[get]
    #
    #     # result = self.mgmt_client.open_shift_managed_clusters.list_by_resource_group(resource_group_name=RESOURCE_GROUP)
    #
    #     # /OpenShiftManagedClusters/get/List Managed Clusters[get]
    #
    #     # result = self.mgmt_client.open_shift_managed_clusters.list()
    #
    #     # /OpenShiftManagedClusters/patch/Update OpenShift Managed Cluster Tags[patch]
    #
    #     BODY = {
    #         "tags": {
    #             "tier": "testing",
    #             "archv3": ""
    #         }
    #     }
    #     # result = self.mgmt_client.open_shift_managed_clusters.begin_update_tags(resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME, parameters=BODY)
    #     # result = result.result()
    #
    #     # /OpenShiftManagedClusters/delete/Delete OpenShift Managed Cluster[delete]
    #
    #     # result = self.mgmt_client.open_shift_managed_clusters.begin_delete(resource_group_name=RESOURCE_GROUP, resource_name=RESOURCE_NAME)
    #     # result = result.result()


if __name__ == "__main__":
    unittest.main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.web import WebSiteManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestWebSiteManagement(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(WebSiteManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_publishing_user(self, resource_group):
        response = self.client.get_publishing_user(
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_update_publishing_user(self, resource_group):
        response = self.client.update_publishing_user(
            user_details={
                "id": "str",
                "kind": "str",
                "name": "str",
                "publishingPassword": "str",
                "publishingPasswordHash": "str",
                "publishingPasswordHashSalt": "str",
                "publishingUserName": "str",
                "scmUri": "str",
                "type": "str",
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_source_controls(self, resource_group):
        response = self.client.list_source_controls(
            api_version="2024-04-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_source_control(self, resource_group):
        response = self.client.get_source_control(
            source_control_type="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_update_source_control(self, resource_group):
        response = self.client.update_source_control(
            source_control_type="str",
            request_message={
                "expirationTime": "2020-02-20 00:00:00",
                "id": "str",
                "kind": "str",
                "name": "str",
                "refreshToken": "str",
                "token": "str",
                "tokenSecret": "str",
                "type": "str",
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_billing_meters(self, resource_group):
        response = self.client.list_billing_meters(
            api_version="2024-04-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_check_name_availability(self, resource_group):
        response = self.client.check_name_availability(
            name="str",
            type="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_custom_host_name_sites(self, resource_group):
        response = self.client.list_custom_host_name_sites(
            api_version="2024-04-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_subscription_deployment_locations(self, resource_group):
        response = self.client.get_subscription_deployment_locations(
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_ase_regions(self, resource_group):
        response = self.client.list_ase_regions(
            api_version="2024-04-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_geo_regions(self, resource_group):
        response = self.client.list_geo_regions(
            api_version="2024-04-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_site_identifiers_assigned_to_host_name(self, resource_group):
        response = self.client.list_site_identifiers_assigned_to_host_name(
            name_identifier={"name": "str"},
            api_version="2024-04-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_premier_add_on_offers(self, resource_group):
        response = self.client.list_premier_add_on_offers(
            api_version="2024-04-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_skus(self, resource_group):
        response = self.client.list_skus(
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_verify_hosting_environment_vnet(self, resource_group):
        response = self.client.verify_hosting_environment_vnet(
            parameters={
                "id": "str",
                "kind": "str",
                "name": "str",
                "subnetResourceId": "str",
                "type": "str",
                "vnetName": "str",
                "vnetResourceGroup": "str",
                "vnetSubnetName": "str",
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_move(self, resource_group):
        response = self.client.move(
            resource_group_name=resource_group.name,
            move_resource_envelope={"resources": ["str"], "targetResourceGroup": "str"},
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_validate(self, resource_group):
        response = self.client.validate(
            resource_group_name=resource_group.name,
            validate_request={
                "location": "str",
                "name": "str",
                "type": "str",
                "appServiceEnvironment": {
                    "virtualNetwork": {"id": "str", "name": "str", "subnet": "str", "type": "str"},
                    "clusterSettings": [{"name": "str", "value": "str"}],
                    "customDnsSuffixConfiguration": {
                        "certificateUrl": "str",
                        "dnsSuffix": "str",
                        "id": "str",
                        "keyVaultReferenceIdentity": "str",
                        "kind": "str",
                        "name": "str",
                        "provisioningDetails": "str",
                        "provisioningState": "str",
                        "type": "str",
                    },
                    "dedicatedHostCount": 0,
                    "dnsSuffix": "str",
                    "frontEndScaleFactor": 0,
                    "hasLinuxWorkers": bool,
                    "internalLoadBalancingMode": "str",
                    "ipsslAddressCount": 0,
                    "maximumNumberOfMachines": 0,
                    "multiRoleCount": 0,
                    "multiSize": "str",
                    "networkingConfiguration": {
                        "allowNewPrivateEndpointConnections": bool,
                        "externalInboundIpAddresses": ["str"],
                        "ftpEnabled": bool,
                        "id": "str",
                        "inboundIpAddressOverride": "str",
                        "internalInboundIpAddresses": ["str"],
                        "kind": "str",
                        "linuxOutboundIpAddresses": ["str"],
                        "name": "str",
                        "remoteDebugEnabled": bool,
                        "type": "str",
                        "windowsOutboundIpAddresses": ["str"],
                    },
                    "provisioningState": "str",
                    "status": "str",
                    "suspended": bool,
                    "upgradeAvailability": "str",
                    "upgradePreference": "None",
                    "userWhitelistedIpRanges": ["str"],
                    "zoneRedundant": bool,
                },
                "capacity": 0,
                "containerImagePlatform": "str",
                "containerImageRepository": "str",
                "containerImageTag": "str",
                "containerRegistryBaseUrl": "str",
                "containerRegistryPassword": "str",
                "containerRegistryUsername": "str",
                "hostingEnvironment": "str",
                "isSpot": bool,
                "isXenon": bool,
                "needLinuxWorkers": bool,
                "serverFarmId": "str",
                "skuName": "str",
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_validate_move(self, resource_group):
        response = self.client.validate_move(
            resource_group_name=resource_group.name,
            move_resource_envelope={"resources": ["str"], "targetResourceGroup": "str"},
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.apimanagement import ApiManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestApiManagementWorkspaceApiOperationOperations(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(ApiManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_operation_list_by_api(self, resource_group):
        response = self.client.workspace_api_operation.list_by_api(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            api_version="2024-05-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_operation_get_entity_tag(self, resource_group):
        response = self.client.workspace_api_operation.get_entity_tag(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            operation_id="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_operation_get(self, resource_group):
        response = self.client.workspace_api_operation.get(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            operation_id="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_operation_create_or_update(self, resource_group):
        response = self.client.workspace_api_operation.create_or_update(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            operation_id="str",
            parameters={
                "description": "str",
                "displayName": "str",
                "id": "str",
                "method": "str",
                "name": "str",
                "policies": "str",
                "request": {
                    "description": "str",
                    "headers": [
                        {
                            "name": "str",
                            "type": "str",
                            "defaultValue": "str",
                            "description": "str",
                            "examples": {
                                "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                            },
                            "required": bool,
                            "schemaId": "str",
                            "typeName": "str",
                            "values": ["str"],
                        }
                    ],
                    "queryParameters": [
                        {
                            "name": "str",
                            "type": "str",
                            "defaultValue": "str",
                            "description": "str",
                            "examples": {
                                "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                            },
                            "required": bool,
                            "schemaId": "str",
                            "typeName": "str",
                            "values": ["str"],
                        }
                    ],
                    "representations": [
                        {
                            "contentType": "str",
                            "examples": {
                                "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                            },
                            "formParameters": [
                                {
                                    "name": "str",
                                    "type": "str",
                                    "defaultValue": "str",
                                    "description": "str",
                                    "examples": {
                                        "str": {
                                            "description": "str",
                                            "externalValue": "str",
                                            "summary": "str",
                                            "value": {},
                                        }
                                    },
                                    "required": bool,
                                    "schemaId": "str",
                                    "typeName": "str",
                                    "values": ["str"],
                                }
                            ],
                            "schemaId": "str",
                            "typeName": "str",
                        }
                    ],
                },
                "responses": [
                    {
                        "statusCode": 0,
                        "description": "str",
                        "headers": [
                            {
                                "name": "str",
                                "type": "str",
                                "defaultValue": "str",
                                "description": "str",
                                "examples": {
                                    "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                                },
                                "required": bool,
                                "schemaId": "str",
                                "typeName": "str",
                                "values": ["str"],
                            }
                        ],
                        "representations": [
                            {
                                "contentType": "str",
                                "examples": {
                                    "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                                },
                                "formParameters": [
                                    {
                                        "name": "str",
                                        "type": "str",
                                        "defaultValue": "str",
                                        "description": "str",
                                        "examples": {
                                            "str": {
                                                "description": "str",
                                                "externalValue": "str",
                                                "summary": "str",
                                                "value": {},
                                            }
                                        },
                                        "required": bool,
                                        "schemaId": "str",
                                        "typeName": "str",
                                        "values": ["str"],
                                    }
                                ],
                                "schemaId": "str",
                                "typeName": "str",
                            }
                        ],
                    }
                ],
                "templateParameters": [
                    {
                        "name": "str",
                        "type": "str",
                        "defaultValue": "str",
                        "description": "str",
                        "examples": {
                            "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                        },
                        "required": bool,
                        "schemaId": "str",
                        "typeName": "str",
                        "values": ["str"],
                    }
                ],
                "type": "str",
                "urlTemplate": "str",
            },
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_operation_update(self, resource_group):
        response = self.client.workspace_api_operation.update(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            operation_id="str",
            if_match="str",
            parameters={
                "description": "str",
                "displayName": "str",
                "method": "str",
                "policies": "str",
                "request": {
                    "description": "str",
                    "headers": [
                        {
                            "name": "str",
                            "type": "str",
                            "defaultValue": "str",
                            "description": "str",
                            "examples": {
                                "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                            },
                            "required": bool,
                            "schemaId": "str",
                            "typeName": "str",
                            "values": ["str"],
                        }
                    ],
                    "queryParameters": [
                        {
                            "name": "str",
                            "type": "str",
                            "defaultValue": "str",
                            "description": "str",
                            "examples": {
                                "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                            },
                            "required": bool,
                            "schemaId": "str",
                            "typeName": "str",
                            "values": ["str"],
                        }
                    ],
                    "representations": [
                        {
                            "contentType": "str",
                            "examples": {
                                "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                            },
                            "formParameters": [
                                {
                                    "name": "str",
                                    "type": "str",
                                    "defaultValue": "str",
                                    "description": "str",
                                    "examples": {
                                        "str": {
                                            "description": "str",
                                            "externalValue": "str",
                                            "summary": "str",
                                            "value": {},
                                        }
                                    },
                                    "required": bool,
                                    "schemaId": "str",
                                    "typeName": "str",
                                    "values": ["str"],
                                }
                            ],
                            "schemaId": "str",
                            "typeName": "str",
                        }
                    ],
                },
                "responses": [
                    {
                        "statusCode": 0,
                        "description": "str",
                        "headers": [
                            {
                                "name": "str",
                                "type": "str",
                                "defaultValue": "str",
                                "description": "str",
                                "examples": {
                                    "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                                },
                                "required": bool,
                                "schemaId": "str",
                                "typeName": "str",
                                "values": ["str"],
                            }
                        ],
                        "representations": [
                            {
                                "contentType": "str",
                                "examples": {
                                    "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                                },
                                "formParameters": [
                                    {
                                        "name": "str",
                                        "type": "str",
                                        "defaultValue": "str",
                                        "description": "str",
                                        "examples": {
                                            "str": {
                                                "description": "str",
                                                "externalValue": "str",
                                                "summary": "str",
                                                "value": {},
                                            }
                                        },
                                        "required": bool,
                                        "schemaId": "str",
                                        "typeName": "str",
                                        "values": ["str"],
                                    }
                                ],
                                "schemaId": "str",
                                "typeName": "str",
                            }
                        ],
                    }
                ],
                "templateParameters": [
                    {
                        "name": "str",
                        "type": "str",
                        "defaultValue": "str",
                        "description": "str",
                        "examples": {
                            "str": {"description": "str", "externalValue": "str", "summary": "str", "value": {}}
                        },
                        "required": bool,
                        "schemaId": "str",
                        "typeName": "str",
                        "values": ["str"],
                    }
                ],
                "urlTemplate": "str",
            },
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_operation_delete(self, resource_group):
        response = self.client.workspace_api_operation.delete(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            operation_id="str",
            if_match="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class ApprovalMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of rule."""

    SINGLE_STAGE = "SingleStage"
    SERIAL = "Serial"
    PARALLEL = "Parallel"
    NO_APPROVAL = "NoApproval"


class EnablementRules(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of enablement rule."""

    MULTI_FACTOR_AUTHENTICATION = "MultiFactorAuthentication"
    JUSTIFICATION = "Justification"
    TICKETING = "Ticketing"


class NotificationDeliveryMechanism(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of notification."""

    EMAIL = "Email"


class NotificationLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The notification level."""

    NONE = "None"
    CRITICAL = "Critical"
    ALL = "All"


class PrincipalType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The principal type of the assigned principal ID."""

    USER = "User"
    GROUP = "Group"
    SERVICE_PRINCIPAL = "ServicePrincipal"
    FOREIGN_GROUP = "ForeignGroup"
    DEVICE = "Device"


class RecipientType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The recipient type."""

    REQUESTOR = "Requestor"
    APPROVER = "Approver"
    ADMIN = "Admin"


class RoleManagementPolicyRuleType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of rule."""

    ROLE_MANAGEMENT_POLICY_APPROVAL_RULE = "RoleManagementPolicyApprovalRule"
    ROLE_MANAGEMENT_POLICY_AUTHENTICATION_CONTEXT_RULE = "RoleManagementPolicyAuthenticationContextRule"
    ROLE_MANAGEMENT_POLICY_ENABLEMENT_RULE = "RoleManagementPolicyEnablementRule"
    ROLE_MANAGEMENT_POLICY_EXPIRATION_RULE = "RoleManagementPolicyExpirationRule"
    ROLE_MANAGEMENT_POLICY_NOTIFICATION_RULE = "RoleManagementPolicyNotificationRule"


class UserType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of user."""

    USER = "User"
    GROUP = "Group"



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.automation import AutomationClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-automation
# USAGE
    python create_or_update_dsc_configuration.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = AutomationClient(
        credential=DefaultAzureCredential(),
        subscription_id="subid",
    )

    response = client.dsc_configuration.create_or_update(
        resource_group_name="rg",
        automation_account_name="myAutomationAccount18",
        configuration_name="SetupServer",
        parameters={
            "location": "East US 2",
            "name": "SetupServer",
            "properties": {
                "description": "sample configuration",
                "source": {
                    "hash": {
                        "algorithm": "sha256",
                        "value": "A9E5DB56BA21513F61E0B3868816FDC6D4DF5131F5617D7FF0D769674BD5072F",
                    },
                    "type": "embeddedContent",
                    "value": 'Configuration SetupServer {\r\n    Node localhost {\r\n                               WindowsFeature IIS {\r\n                               Name = "Web-Server";\r\n            Ensure = "Present"\r\n        }\r\n    }\r\n}',
                },
            },
        },
    )
    print(response)


# x-ms-original-file: specification/automation/resource-manager/Microsoft.Automation/stable/2022-08-08/examples/createOrUpdateDscConfiguration.json
if __name__ == "__main__":
    main()
